==> stooop-3.3.tar.gz: stooop-3.3/37.tcl <==
source parray.tcl
source stooop.tcl
namespace import stooop::*

### check that multiply inherited base classes constructors work with variable number of arguments
# (see 72.tcl for nested class version)

# expected output:

## a::a 1 {1 2} 3
## b::b 1 x y
## c::c 1 x y {1 2} 3
## d::d 1 x y {1 2} 3
## a::(1,_derived) = ::d
## a::(1,m) = 1 2
## b::(1,_derived) = ::d
## b::(1,n) = x y
## c::(1,_derived) = ::d
## c::(1,o) = x y
## c::(1,p) = 1 2
## d::(1,q) = x y
## d::(1,r) = 1 2

## A::A 2 {1 2} 3
## B::B 2 x y
## C::C 2 x y {1 2} 3
## D::D 2 x y {1 2} 3
## A::(2,_derived) = ::D
## A::(2,m) = 1 2
## B::(2,_derived) = ::D
## B::(2,n) = x y
## C::(2,_derived) = ::D
## C::(2,o) = x y
## C::(2,p) = 1 2
## D::(2,q) = x y
## D::(2,r) = 1 2

class a {}
proc a::a {this args} {
    puts "a::a $this $args"
    set a::($this,m) [lindex $args 0]
}
class b {}
proc b::b {this p} {
    puts "b::b $this $p"
    set b::($this,n) $p
}
class c {}
proc c::c {this p args} {
    puts "c::c $this $p $args"
    set c::($this,o) $p
    set c::($this,p) [lindex $args 0]
}
class d {}
proc d::d {this p args} a {$args} b {$p} c {$p $args} {
    puts "d::d $this $p $args"
    set d::($this,q) $p
    set d::($this,r) [lindex $args 0]
}
new d {x y} {1 2} 3
printArrays a:: b:: c:: d::

class A {
    proc A {this args} {
        puts "A::A $this $args"
        set A::($this,m) [lindex $args 0]
    }
}
class B {
    proc B {this p} {
        puts "B::B $this $p"
        set B::($this,n) $p
    }
}
class C {
    proc C {this p args} {
        puts "C::C $this $p $args"
        set C::($this,o) $p
        set C::($this,p) [lindex $args 0]
    }
}
class D {
    proc D {this p args} A {$args} B {$p} C {$p $args} {
        puts "D::D $this $p $args"
        set D::($this,q) $p
        set D::($this,r) [lindex $args 0]
    }
}
new D {x y} {1 2} 3
printArrays A:: B:: C:: D::

==> stooop-4.1.1.tar.gz: stooop-4.1.1/37.tcl <==
source parray.tcl
source stooop.tcl
namespace import stooop::*

### check that multiply inherited base classes constructors work with variable number of arguments
# (see 72.tcl for nested class version)

# expected output:

## a::a 1 {1 2} 3
## b::b 1 x y
## c::c 1 x y {1 2} 3
## d::d 1 x y {1 2} 3
## a::(1,_derived) = ::d
## a::(1,m) = 1 2
## b::(1,_derived) = ::d
## b::(1,n) = x y
## c::(1,_derived) = ::d
## c::(1,o) = x y
## c::(1,p) = 1 2
## d::(1,q) = x y
## d::(1,r) = 1 2

## A::A 2 {1 2} 3
## B::B 2 x y
## C::C 2 x y {1 2} 3
## D::D 2 x y {1 2} 3
## A::(2,_derived) = ::D
## A::(2,m) = 1 2
## B::(2,_derived) = ::D
## B::(2,n) = x y
## C::(2,_derived) = ::D
## C::(2,o) = x y
## C::(2,p) = 1 2
## D::(2,q) = x y
## D::(2,r) = 1 2

class a {}
proc a::a {this args} {
    puts "a::a $this $args"
    set ($this,m) [lindex $args 0]
}
class b {}
proc b::b {this p} {
    puts "b::b $this $p"
    set ($this,n) $p
}
class c {}
proc c::c {this p args} {
    puts "c::c $this $p $args"
    set ($this,o) $p
    set ($this,p) [lindex $args 0]
}
class d {}
proc d::d {this p args} a {$args} b {$p} c {$p $args} {
    puts "d::d $this $p $args"
    set ($this,q) $p
    set ($this,r) [lindex $args 0]
}
new d {x y} {1 2} 3
printArrays a:: b:: c:: d::

class A {
    proc A {this args} {
        puts "A::A $this $args"
        set ($this,m) [lindex $args 0]
    }
}
class B {
    proc B {this p} {
        puts "B::B $this $p"
        set ($this,n) $p
    }
}
class C {
    proc C {this p args} {
        puts "C::C $this $p $args"
        set ($this,o) $p
        set ($this,p) [lindex $args 0]
    }
}
class D {
    proc D {this p args} A {$args} B {$p} C {$p $args} {
        puts "D::D $this $p $args"
        set ($this,q) $p
        set ($this,r) [lindex $args 0]
    }
}
new D {x y} {1 2} 3
printArrays A:: B:: C:: D::
